diff --git a/README.markdown b/README.markdown
index 61c0bdcf9..22b8a51f4 100644
--- a/README.markdown
+++ b/README.markdown
@@ -149,6 +149,7 @@ Handlebars in the Wild
 * [YUI](http://yuilibrary.com/yui/docs/handlebars/) implements a port of handlebars
 * [Swag](https://github.com/elving/swag) by [@elving](https://github.com/elving) is a growing collection of helpers for handlebars.js. Give your handlebars.js templates some swag son!
 * [DOMBars](https://github.com/blakeembrey/dombars) is a DOM-based templating engine built on the Handlebars parser and runtime
+* [promised-handlebars](https://github.com/nknapp/promised-handlebars) is a wrapper for Handlebars that allows helpers to return Promises.
 
 External Resources
 ------------------
diff --git a/components/bower.json b/components/bower.json
index 5751938d6..e4aaab97e 100644
--- a/components/bower.json
+++ b/components/bower.json
@@ -1,6 +1,6 @@
 {
   "name": "handlebars",
-  "version": "4.0.3",
+  "version": "4.0.4",
   "main": "handlebars.js",
   "license": "MIT",
   "dependencies": {}
diff --git a/components/handlebars.js.nuspec b/components/handlebars.js.nuspec
index 56899417c..326827e16 100644
--- a/components/handlebars.js.nuspec
+++ b/components/handlebars.js.nuspec
@@ -2,7 +2,7 @@
 <package>
 	<metadata>
 		<id>handlebars.js</id>
-		<version>4.0.3</version>
+		<version>4.0.4</version>
 		<authors>handlebars.js Authors</authors>
 		<licenseUrl>https://github.com/wycats/handlebars.js/blob/master/LICENSE</licenseUrl>
 		<projectUrl>https://github.com/wycats/handlebars.js/</projectUrl>
diff --git a/lib/handlebars/base.js b/lib/handlebars/base.js
index 67fcc206c..84a89158f 100644
--- a/lib/handlebars/base.js
+++ b/lib/handlebars/base.js
@@ -4,7 +4,7 @@ import {registerDefaultHelpers} from './helpers';
 import {registerDefaultDecorators} from './decorators';
 import logger from './logger';
 
-export const VERSION = '4.0.3';
+export const VERSION = '4.0.4';
 export const COMPILER_REVISION = 7;
 
 export const REVISION_CHANGES = {
@@ -51,7 +51,7 @@ HandlebarsEnvironment.prototype = {
       extend(this.partials, name);
     } else {
       if (typeof partial === 'undefined') {
-        throw new Exception('Attempting to register a partial as undefined');
+        throw new Exception(`Attempting to register a partial called "${name}" as undefined`);
       }
       this.partials[name] = partial;
     }
diff --git a/package.json b/package.json
index 9d6c0b66a..605380365 100644
--- a/package.json
+++ b/package.json
@@ -1,7 +1,7 @@
 {
   "name": "handlebars",
   "barename": "handlebars",
-  "version": "4.0.3",
+  "version": "4.0.4",
   "description": "Handlebars provides the power necessary to let you build semantic templates effectively with no frustration",
   "homepage": "http://www.handlebarsjs.com/",
   "keywords": [
diff --git a/release-notes.md b/release-notes.md
index 9736ad093..5ea873efe 100644
--- a/release-notes.md
+++ b/release-notes.md
@@ -2,7 +2,13 @@
 
 ## Development
 
-[Commits](https://github.com/wycats/handlebars.js/compare/v4.0.3...master)
+[Commits](https://github.com/wycats/handlebars.js/compare/v4.0.4...master)
+
+## v4.0.4 - October 29th, 2015
+- [#1121](https://github.com/wycats/handlebars.js/pull/1121) - Include partial name in 'undefined partial' exception message ([@shinypb](https://api.github.com/users/shinypb))
+- [#1125](https://github.com/wycats/handlebars.js/pull/1125) - Add promised-handlebars to "in-the-wild"-list ([@nknapp](https://api.github.com/users/nknapp))
+
+[Commits](https://github.com/wycats/handlebars.js/compare/v4.0.3...v4.0.4)
 
 ## v4.0.3 - September 23rd, 2015
 - [#1099](https://github.com/wycats/handlebars.js/issues/1099) - @partial-block is overridden ([@btmorex](https://api.github.com/users/btmorex))
diff --git a/spec/partials.js b/spec/partials.js
index cc2c266e7..d3ead7458 100644
--- a/spec/partials.js
+++ b/spec/partials.js
@@ -103,7 +103,7 @@ describe('partials', function() {
     shouldThrow(function() {
       var undef;
       handlebarsEnv.registerPartial('undefined_test', undef);
-    }, Handlebars.Exception, 'Attempting to register a partial as undefined');
+    }, Handlebars.Exception, 'Attempting to register a partial called "undefined_test" as undefined');
   });
 
   it('rendering template partial in vm mode throws an exception', function() {
